/*
	Based on "QuerySoundPlay" by Marco Nelissen. Some modifications made to output, 
	including the addition of a "bitrate" check and the removal of Baxter-related 
	code.. Thanks to Allen on BeShare for helping with the sprintf() issue, and 
	especially thanks to Marco for creating SoundPlay :)
	
	Original Description: 
	Application that directs Baxter to show what SoundPlay is currently	playing.
	Similar to "QueryCLAmp", except that this application is smaller and uses
	the standard BeOS scripting mechanism.
*/


#include <Application.h>
#include <Message.h>
#include <stdio.h>
#include <stdlib.h>

int main(int argc, char *argv[])
{
	int CmdLine = 0;

	BApplication app("application/x-vnd.abisoft-BaxterRemoteTest");
	
	if(argc >= 2)
 	   CmdLine = atoi(argv[1]);
	   
	BMessage question(B_GET_PROPERTY);
	question.AddSpecifier("info");
	question.AddSpecifier("track",int32(CmdLine));
	BMessage answer;

	if(B_OK==BMessenger("application/x-vnd.marcone-soundplay").SendMessage(&question, &answer,2E6,2E6))
	{
		double pitch;
		double time;
		double totaltime;
		double bitrate;
		const char *name;
		
		char buf[1024];
		buf[0] = '\0';

		if(	B_OK==answer.FindDouble("pitch",&pitch) &&
			B_OK==answer.FindDouble("abspos",&time) &&
			B_OK==answer.FindDouble("length",&totaltime) &&
			B_OK==answer.FindDouble("bitrate",&bitrate) &&
			B_OK==answer.FindString("name",&name))
		{

			if(answer.FindBool("unknownlength"))
				sprintf(buf, "SoundPlay is currently playing \"%s\"",name);
			else if(pitch!=0.0)
				sprintf(buf, "\"%s\" [ %ld:%02ld/%ld:%02ld (%ld:%02ld remaining) | %ld kbps ]",
					name, 
					int(time)/60,
					int(time)%60,
					int(totaltime)/60,
					int(totaltime)%60,
					int(totaltime-time)/60,
					int(totaltime-time)%60,
					int(bitrate)/1000);
		}
		printf("%s\n", buf);
		if(buf[0] == '\0')
			return 1;

		return 0;
	}
	return 1;
}
